@@ -206,7 +206,7 @@ bool maybeThrowBackCompatKeepdimWarn(char* func);
 
 // NB: This is in torch/csrc/cuda/utils.cpp, for whatever reason
 #ifdef USE_ROCM
-std::vector<c10::optional<at::hip::HIPStreamMasqueradingAsCUDA>>
+std::vector<std::optional<at::hip::HIPStreamMasqueradingAsCUDA>>
 THPUtils_PySequence_to_CUDAStreamList(PyObject* obj);
 #endif
 
